@@ -73,7 +73,7 @@ class Ui_MainWindow(QMainWindow):
         self.options = parse_config(self,GnGeo_CfgFile)
 	AllGnGeoOpts = [ "68kclock", "autoframeskip", "biospath", "country", "effect", "fullscreen", "hwsurface", 
 	                 "interpolation", "joystick", "p1joy", "p1joydev", "p2key", "p2joy", "p2joydev", "p2key", "raster", 
-	                 "romrcdir", "samplerate", "scale", "showfps", "sleepidle", "sund", "system", "z80clock" ]
+	                 "romrcdir", "samplerate", "scale", "showfps", "sleepidle", "sound", "system", "z80clock" ]
 	for GnGeoOpt in AllGnGeoOpts:
 		try:
 			 self.options[GnGeoOpt]
